@@ -11,7 +11,8 @@ shiny_vector_filter_ui.NULL = function(data, inputId) {
 #' @keywords internal
 shiny_vector_filter.NULL <- function(data, inputId, ...) {
   function(input, output, session, x = shiny::reactive(NULL), 
-    filter_na = shiny::reactive(FALSE), verbose = FALSE) { 
+    filter_na = shiny::reactive(FALSE), filter_fn = NULL, verbose = FALSE,
+    erase_filters = shiny::reactive(0)) { 
     
     module_return <- shiny::reactiveValues(code = TRUE, mask = TRUE)
     module_return$code <- shiny::reactive(TRUE)
@@ -19,4 +20,4 @@ shiny_vector_filter.NULL <- function(data, inputId, ...) {
     
     module_return
   }
-}
\ No newline at end of file
+}
